function [w,f] = proxGradLasso(X,y,lambda,maxEvals)

[n,d] = size(X);

% Compute Lipschitz constant and step size
L = max(eig(X'*X));
alpha = 1/L;

% Evaluate initial objective and gradient of smooth part
w = zeros(d,1);
f = (1/2)*sum((X*w-y).^2) + lambda*sum(abs(w));
g = X'*(X*w - y);
funEvals = 1;

while funEvals < maxEvals
    
    % proximal-gradient step
    w = softThreshold(w - alpha*g,alpha*lambda);
    
    % Evaluate new function and gradient value
    f = (1/2)*sum((X*w-y).^2) + lambda*sum(abs(w));
    g = X'*(X*w - y);
    funEvals = funEvals + 1;
    
    % Print out how we are doing
    optCond = norm(w-softThreshold(w-g,lambda),'inf');
    fprintf('%6d %15.5e %15.5e %15.5e\n',funEvals,alpha,f,optCond);
    
    if optCond < 1e-1
        break;
    end
end
pause
end

function [w] = softThreshold(w,threshold)
    w = sign(w).*max(0,abs(w)-threshold);
end
